import { Project } from "ts-morph";
export declare type TagType = {
    name: string;
    value: string;
};
export declare type PropertyType = {
    name: string;
    type: string;
    isOptional: boolean;
    tags: TagType[];
};
export declare type FunctionSchema = {
    tags: TagType[];
    params: Array<PropertyType & {
        initializerText: string | null;
    }>;
    returns: string;
};
export declare type InterfaceSchema = {
    tags: TagType[];
    data: PropertyType[];
};
export declare type Schema = FunctionSchema | InterfaceSchema;
export declare type MarkdownTableType = 'interface' | 'parameter';
export declare type DefaultTypeMapT = Record<string, {
    type: string;
    tags: TagType[];
}>;
export declare type GenerateConfig = {
    defaultTypeMap?: DefaultTypeMapT;
    sourceFilesPaths: string | string[];
    /**
     * Whether to skip parsing documentation comment as property description
     */
    strictComment?: boolean;
    /**
     * Generate schema in the order they appear in the document
     * When it's true, generate function will return Array<{ title: string; schema: Schema }>
     */
    strictDeclarationOrder?: boolean;
    /**
     * The compare function to sort properties/arguments of schema
     */
    propertySorter?: (a: PropertyType, b: typeof a) => number;
    /**
     * Custom project to use in generate function
     */
    project?: Project;
};
export declare type GenerateMarkdownConfig = GenerateConfig & {
    lang?: string;
};
